==> libuhd-docs-4.8.0.0-7-x86_64.pkg.tar.zst: usr/share/doc/uhd/doxygen/html/search/variables_12.js <==
var searchData=
[
  ['sd_5fname_0',['sd_name',['../structuhd__subdev__spec__pair__t.html#a9c85d6cf58b9d477003694c1a4b59350',1,'uhd_subdev_spec_pair_t::sd_name'],['../structuhd_1_1usrp_1_1subdev__spec__pair__t.html#a2446ca125e631b7c7fd9171ba7383067',1,'uhd::usrp::subdev_spec_pair_t::sd_name']]],
  ['send_5fbuff_5fsize_1',['send_buff_size',['../structuhd_1_1transport_1_1udp__zero__copy_1_1buff__params.html#a8685f52397386257eb6a3bc58f9264dd',1,'uhd::transport::udp_zero_copy::buff_params::send_buff_size'],['../structuhd_1_1transport_1_1zero__copy__xport__params.html#a214711e37bd81c90fd4795540271762a',1,'uhd::transport::zero_copy_xport_params::send_buff_size']]],
  ['send_5fframe_5fsize_2',['send_frame_size',['../structuhd_1_1transport_1_1zero__copy__xport__params.html#a31d6a719fdf042593c38de4d1b4e38bc',1,'uhd::transport::zero_copy_xport_params']]],
  ['seq_5fnum_3',['seq_num',['../classuhd_1_1rfnoc_1_1chdr_1_1ctrl__payload.html#aa2d2168eecb48057c0708ca5ee5e082c',1,'uhd::rfnoc::chdr::ctrl_payload']]],
  ['serial_4',['serial',['../structuhd_1_1usrp_1_1dboard__eeprom__t.html#ac41565ca47b70c83565f91c8b2a389c0',1,'uhd::usrp::dboard_eeprom_t']]],
  ['set_5fvalue_5',['set_value',['../structuhd_1_1gain__fcns__t.html#a70a17b1c9d04ccaea00dd87fa9a9d62b',1,'uhd::gain_fcns_t']]],
  ['shell_6',['shell',['../namespaceconf.html#a332f430461432dc465213f884a1e4967',1,'conf']]],
  ['sid_7',['sid',['../structuhd_1_1transport_1_1vrt_1_1if__packet__info__t.html#a388a47b306e55ebf9eccf8f052302cbc',1,'uhd::transport::vrt::if_packet_info_t']]],
  ['sob_8',['sob',['../structuhd_1_1transport_1_1vrt_1_1if__packet__info__t.html#a5f63fc4d646221211758f8a611be2202',1,'uhd::transport::vrt::if_packet_info_t']]],
  ['soft_5fclock_5fdivider_9',['soft_clock_divider',['../structuhd_1_1usrp_1_1dboard__iface__special__props__t.html#a9a9bce30eeff1d7966173834346d3fd1',1,'uhd::usrp::dboard_iface_special_props_t']]],
  ['source_5fsuffix_10',['source_suffix',['../namespaceconf.html#ad15efa571aa0827e142708247b74ee13',1,'conf']]],
  ['sr_5fcoeffs_5faddr_11',['SR_COEFFS_ADDR',['../classuhd_1_1rfnoc_1_1ddc__block__control.html#adea9b73ff5dce6a40c7427e447418c05',1,'uhd::rfnoc::ddc_block_control']]],
  ['sr_5fconfig_5faddr_12',['SR_CONFIG_ADDR',['../classuhd_1_1rfnoc_1_1ddc__block__control.html#a1955bbec616e53ec69c42bb43683d000',1,'uhd::rfnoc::ddc_block_control::SR_CONFIG_ADDR'],['../classuhd_1_1rfnoc_1_1duc__block__control.html#ae8fb2de583b83915127a0575ddd2fa6a',1,'uhd::rfnoc::duc_block_control::SR_CONFIG_ADDR']]],
  ['sr_5fdecim_5faddr_13',['SR_DECIM_ADDR',['../classuhd_1_1rfnoc_1_1ddc__block__control.html#a4d45dbe937b6e6c0e1f7641141193e41',1,'uhd::rfnoc::ddc_block_control']]],
  ['sr_5ffreq_5faddr_14',['SR_FREQ_ADDR',['../classuhd_1_1rfnoc_1_1ddc__block__control.html#a45d91d24686450233d5f3a3388865746',1,'uhd::rfnoc::ddc_block_control::SR_FREQ_ADDR'],['../classuhd_1_1rfnoc_1_1duc__block__control.html#ac72eca654d9ac62bcb1808d1d95cf32b',1,'uhd::rfnoc::duc_block_control::SR_FREQ_ADDR']]],
  ['sr_5finterp_5faddr_15',['SR_INTERP_ADDR',['../classuhd_1_1rfnoc_1_1duc__block__control.html#ad8323429da7e5e3143e3247f965fc1d3',1,'uhd::rfnoc::duc_block_control']]],
  ['sr_5fm_5faddr_16',['SR_M_ADDR',['../classuhd_1_1rfnoc_1_1ddc__block__control.html#abcaf7c41c393f27020297936fa7788e4',1,'uhd::rfnoc::ddc_block_control::SR_M_ADDR'],['../classuhd_1_1rfnoc_1_1duc__block__control.html#a9e172a0cd7791bdca459205a8d216621',1,'uhd::rfnoc::duc_block_control::SR_M_ADDR']]],
  ['sr_5fmux_5faddr_17',['SR_MUX_ADDR',['../classuhd_1_1rfnoc_1_1ddc__block__control.html#a0388ec3f67e191f9af28f17f86ec504e',1,'uhd::rfnoc::ddc_block_control']]],
  ['sr_5fn_5faddr_18',['SR_N_ADDR',['../classuhd_1_1rfnoc_1_1ddc__block__control.html#adcb6ec71428a1cf087d0e151d4bdcab8',1,'uhd::rfnoc::ddc_block_control::SR_N_ADDR'],['../classuhd_1_1rfnoc_1_1duc__block__control.html#ac256c5f166f344e25385967cc5c1763c',1,'uhd::rfnoc::duc_block_control::SR_N_ADDR']]],
  ['sr_5fscale_5fiq_5faddr_19',['SR_SCALE_IQ_ADDR',['../classuhd_1_1rfnoc_1_1ddc__block__control.html#abda85c9e643fe158bd68e6c37189d9e9',1,'uhd::rfnoc::ddc_block_control::SR_SCALE_IQ_ADDR'],['../classuhd_1_1rfnoc_1_1duc__block__control.html#aaae8af2f2ae3784a9a7b15db26b052d5',1,'uhd::rfnoc::duc_block_control::SR_SCALE_IQ_ADDR']]],
  ['sr_5ftime_5fincr_5faddr_20',['SR_TIME_INCR_ADDR',['../classuhd_1_1rfnoc_1_1ddc__block__control.html#a31c46fa96cda3e2c7798f1028841b6ec',1,'uhd::rfnoc::ddc_block_control::SR_TIME_INCR_ADDR'],['../classuhd_1_1rfnoc_1_1duc__block__control.html#aefc3aa9c367177dc42ba13c9a4bea031',1,'uhd::rfnoc::duc_block_control::SR_TIME_INCR_ADDR']]],
  ['src_5fblockid_21',['src_blockid',['../structuhd_1_1rfnoc_1_1graph__edge__t.html#a8267aa23a6da0c34f09789876a7e0cb8',1,'uhd::rfnoc::graph_edge_t']]],
  ['src_5fepid_22',['src_epid',['../classuhd_1_1rfnoc_1_1chdr_1_1ctrl__payload.html#a6bbb254b101d12e9fa377cdfe7d83ba7',1,'uhd::rfnoc::chdr::ctrl_payload::src_epid'],['../classuhd_1_1rfnoc_1_1chdr_1_1strs__payload.html#a1888c5df43911569a22df42536e8d15b',1,'uhd::rfnoc::chdr::strs_payload::src_epid'],['../classuhd_1_1rfnoc_1_1chdr_1_1strc__payload.html#a203abf70917d41debac4ccd9e0d2569c',1,'uhd::rfnoc::chdr::strc_payload::src_epid']]],
  ['src_5fport_23',['src_port',['../classuhd_1_1rfnoc_1_1chdr_1_1ctrl__payload.html#a4411d237737d918d0db3b199eea1d96d',1,'uhd::rfnoc::chdr::ctrl_payload::src_port'],['../structuhd_1_1rfnoc_1_1graph__edge__t.html#ae8004026202e4680d6698c0dc8270d55',1,'uhd::rfnoc::graph_edge_t::src_port']]],
  ['start_24',['start',['../structuhd__range__t.html#ae6592e7bf65825e92f965c7aad022914',1,'uhd_range_t']]],
  ['start_5fof_5fburst_25',['start_of_burst',['../structuhd_1_1rx__metadata__t.html#ac36a6c9889ccbac4999496e3681eb088',1,'uhd::rx_metadata_t::start_of_burst'],['../structuhd_1_1tx__metadata__t.html#ab5ffe812f8d3d1870253e98e6ff1718a',1,'uhd::tx_metadata_t::start_of_burst']]],
  ['status_26',['status',['../classuhd_1_1rfnoc_1_1chdr_1_1ctrl__payload.html#a8aab61504380659c84fecb98bd4dfb48',1,'uhd::rfnoc::chdr::ctrl_payload::status'],['../classuhd_1_1rfnoc_1_1chdr_1_1strs__payload.html#ad480749a0f62d2b65439f6db75180c9b',1,'uhd::rfnoc::chdr::strs_payload::status']]],
  ['status_5finfo_27',['status_info',['../classuhd_1_1rfnoc_1_1chdr_1_1strs__payload.html#a347a202ac771b6fcdc469b46d3a018e3',1,'uhd::rfnoc::chdr::strs_payload']]],
  ['step_28',['step',['../structuhd__range__t.html#af833ecfd9e3c97e02b42f64cbe9b70ad',1,'uhd_range_t']]],
  ['stop_29',['stop',['../structuhd__range__t.html#aa5087b5f114a9dbc91c0b448af10a156',1,'uhd_range_t']]],
  ['stream_5fcmd_30',['stream_cmd',['../structuhd_1_1rfnoc_1_1stream__cmd__action__info.html#af61e2768b2eb7152b5a5985c38219864',1,'uhd::rfnoc::stream_cmd_action_info']]],
  ['stream_5fmode_31',['stream_mode',['../structuhd_1_1stream__cmd__t.html#afc034937887f08dc6119cf96b0c02f5d',1,'uhd::stream_cmd_t::stream_mode'],['../structuhd__stream__cmd__t.html#a7a554a47849307827e4e067a3c7a3db3',1,'uhd_stream_cmd_t::stream_mode']]],
  ['stream_5fnow_32',['stream_now',['../structuhd_1_1stream__cmd__t.html#a0b2ebd1dedd814355c3fcd51af7d1eb1',1,'uhd::stream_cmd_t::stream_now'],['../structuhd__stream__cmd__t.html#a49d87875f02323627803db3df305b43b',1,'uhd_stream_cmd_t::stream_now']]]
];

==> libuhd-docs-4.9.0.1-1-x86_64.pkg.tar.zst: usr/share/doc/uhd/doxygen/html/search/variables_12.js <==
var searchData=
[
  ['sd_5fname_0',['sd_name',['../structuhd__subdev__spec__pair__t.html#a9c85d6cf58b9d477003694c1a4b59350',1,'uhd_subdev_spec_pair_t::sd_name'],['../structuhd_1_1usrp_1_1subdev__spec__pair__t.html#a2446ca125e631b7c7fd9171ba7383067',1,'uhd::usrp::subdev_spec_pair_t::sd_name']]],
  ['send_5fbuff_5fsize_1',['send_buff_size',['../structuhd_1_1transport_1_1udp__zero__copy_1_1buff__params.html#a8685f52397386257eb6a3bc58f9264dd',1,'uhd::transport::udp_zero_copy::buff_params::send_buff_size'],['../structuhd_1_1transport_1_1zero__copy__xport__params.html#a214711e37bd81c90fd4795540271762a',1,'uhd::transport::zero_copy_xport_params::send_buff_size']]],
  ['send_5fframe_5fsize_2',['send_frame_size',['../structuhd_1_1transport_1_1zero__copy__xport__params.html#a31d6a719fdf042593c38de4d1b4e38bc',1,'uhd::transport::zero_copy_xport_params']]],
  ['seq_5ferror_5foccoured_3',['seq_error_occoured',['../classuhd_1_1rfnoc_1_1chdr_1_1strs__payload.html#a2f27a4643d65397a16bf7f537706abee',1,'uhd::rfnoc::chdr::strs_payload']]],
  ['seq_5fnum_4',['seq_num',['../classuhd_1_1rfnoc_1_1chdr_1_1ctrl__payload.html#aa2d2168eecb48057c0708ca5ee5e082c',1,'uhd::rfnoc::chdr::ctrl_payload']]],
  ['sequence_5ferror_5',['sequence_error',['../classuhd_1_1rfnoc_1_1chdr_1_1strs__payload.html#aee5812e7365b983d55ac25d5be304f5a',1,'uhd::rfnoc::chdr::strs_payload']]],
  ['serial_6',['serial',['../structuhd_1_1usrp_1_1dboard__eeprom__t.html#ac41565ca47b70c83565f91c8b2a389c0',1,'uhd::usrp::dboard_eeprom_t']]],
  ['set_5fvalue_7',['set_value',['../structuhd_1_1gain__fcns__t.html#a70a17b1c9d04ccaea00dd87fa9a9d62b',1,'uhd::gain_fcns_t']]],
  ['sid_8',['sid',['../structuhd_1_1transport_1_1vrt_1_1if__packet__info__t.html#a388a47b306e55ebf9eccf8f052302cbc',1,'uhd::transport::vrt::if_packet_info_t']]],
  ['sob_9',['sob',['../structuhd_1_1transport_1_1vrt_1_1if__packet__info__t.html#a5f63fc4d646221211758f8a611be2202',1,'uhd::transport::vrt::if_packet_info_t']]],
  ['soft_5fclock_5fdivider_10',['soft_clock_divider',['../structuhd_1_1usrp_1_1dboard__iface__special__props__t.html#a9a9bce30eeff1d7966173834346d3fd1',1,'uhd::usrp::dboard_iface_special_props_t']]],
  ['sr_5fcoeffs_5faddr_11',['SR_COEFFS_ADDR',['../classuhd_1_1rfnoc_1_1ddc__block__control.html#adea9b73ff5dce6a40c7427e447418c05',1,'uhd::rfnoc::ddc_block_control']]],
  ['sr_5fconfig_5faddr_12',['SR_CONFIG_ADDR',['../classuhd_1_1rfnoc_1_1ddc__block__control.html#a1955bbec616e53ec69c42bb43683d000',1,'uhd::rfnoc::ddc_block_control::SR_CONFIG_ADDR'],['../classuhd_1_1rfnoc_1_1duc__block__control.html#ae8fb2de583b83915127a0575ddd2fa6a',1,'uhd::rfnoc::duc_block_control::SR_CONFIG_ADDR']]],
  ['sr_5fdecim_5faddr_13',['SR_DECIM_ADDR',['../classuhd_1_1rfnoc_1_1ddc__block__control.html#a4d45dbe937b6e6c0e1f7641141193e41',1,'uhd::rfnoc::ddc_block_control']]],
  ['sr_5ffreq_5faddr_14',['SR_FREQ_ADDR',['../classuhd_1_1rfnoc_1_1ddc__block__control.html#a45d91d24686450233d5f3a3388865746',1,'uhd::rfnoc::ddc_block_control::SR_FREQ_ADDR'],['../classuhd_1_1rfnoc_1_1duc__block__control.html#ac72eca654d9ac62bcb1808d1d95cf32b',1,'uhd::rfnoc::duc_block_control::SR_FREQ_ADDR']]],
  ['sr_5finterp_5faddr_15',['SR_INTERP_ADDR',['../classuhd_1_1rfnoc_1_1duc__block__control.html#ad8323429da7e5e3143e3247f965fc1d3',1,'uhd::rfnoc::duc_block_control']]],
  ['sr_5fm_5faddr_16',['SR_M_ADDR',['../classuhd_1_1rfnoc_1_1ddc__block__control.html#abcaf7c41c393f27020297936fa7788e4',1,'uhd::rfnoc::ddc_block_control::SR_M_ADDR'],['../classuhd_1_1rfnoc_1_1duc__block__control.html#a9e172a0cd7791bdca459205a8d216621',1,'uhd::rfnoc::duc_block_control::SR_M_ADDR']]],
  ['sr_5fmux_5faddr_17',['SR_MUX_ADDR',['../classuhd_1_1rfnoc_1_1ddc__block__control.html#a0388ec3f67e191f9af28f17f86ec504e',1,'uhd::rfnoc::ddc_block_control']]],
  ['sr_5fn_5faddr_18',['SR_N_ADDR',['../classuhd_1_1rfnoc_1_1ddc__block__control.html#adcb6ec71428a1cf087d0e151d4bdcab8',1,'uhd::rfnoc::ddc_block_control::SR_N_ADDR'],['../classuhd_1_1rfnoc_1_1duc__block__control.html#ac256c5f166f344e25385967cc5c1763c',1,'uhd::rfnoc::duc_block_control::SR_N_ADDR']]],
  ['sr_5fscale_5fiq_5faddr_19',['SR_SCALE_IQ_ADDR',['../classuhd_1_1rfnoc_1_1ddc__block__control.html#abda85c9e643fe158bd68e6c37189d9e9',1,'uhd::rfnoc::ddc_block_control::SR_SCALE_IQ_ADDR'],['../classuhd_1_1rfnoc_1_1duc__block__control.html#aaae8af2f2ae3784a9a7b15db26b052d5',1,'uhd::rfnoc::duc_block_control::SR_SCALE_IQ_ADDR']]],
  ['sr_5ftime_5fincr_5faddr_20',['SR_TIME_INCR_ADDR',['../classuhd_1_1rfnoc_1_1ddc__block__control.html#a31c46fa96cda3e2c7798f1028841b6ec',1,'uhd::rfnoc::ddc_block_control::SR_TIME_INCR_ADDR'],['../classuhd_1_1rfnoc_1_1duc__block__control.html#aefc3aa9c367177dc42ba13c9a4bea031',1,'uhd::rfnoc::duc_block_control::SR_TIME_INCR_ADDR']]],
  ['src_5fblockid_21',['src_blockid',['../structuhd_1_1rfnoc_1_1graph__edge__t.html#a8267aa23a6da0c34f09789876a7e0cb8',1,'uhd::rfnoc::graph_edge_t']]],
  ['src_5fepid_22',['src_epid',['../classuhd_1_1rfnoc_1_1chdr_1_1ctrl__payload.html#a6bbb254b101d12e9fa377cdfe7d83ba7',1,'uhd::rfnoc::chdr::ctrl_payload::src_epid'],['../classuhd_1_1rfnoc_1_1chdr_1_1strs__payload.html#a1888c5df43911569a22df42536e8d15b',1,'uhd::rfnoc::chdr::strs_payload::src_epid'],['../classuhd_1_1rfnoc_1_1chdr_1_1strc__payload.html#a203abf70917d41debac4ccd9e0d2569c',1,'uhd::rfnoc::chdr::strc_payload::src_epid']]],
  ['src_5fport_23',['src_port',['../classuhd_1_1rfnoc_1_1chdr_1_1ctrl__payload.html#a4411d237737d918d0db3b199eea1d96d',1,'uhd::rfnoc::chdr::ctrl_payload::src_port'],['../structuhd_1_1rfnoc_1_1graph__edge__t.html#ae8004026202e4680d6698c0dc8270d55',1,'uhd::rfnoc::graph_edge_t::src_port']]],
  ['start_24',['start',['../structuhd__range__t.html#ae6592e7bf65825e92f965c7aad022914',1,'uhd_range_t']]],
  ['start_5fof_5fburst_25',['start_of_burst',['../structuhd_1_1rx__metadata__t.html#ac36a6c9889ccbac4999496e3681eb088',1,'uhd::rx_metadata_t::start_of_burst'],['../structuhd_1_1tx__metadata__t.html#ab5ffe812f8d3d1870253e98e6ff1718a',1,'uhd::tx_metadata_t::start_of_burst']]],
  ['status_26',['status',['../classuhd_1_1rfnoc_1_1chdr_1_1ctrl__payload.html#a8aab61504380659c84fecb98bd4dfb48',1,'uhd::rfnoc::chdr::ctrl_payload::status'],['../classuhd_1_1rfnoc_1_1chdr_1_1strs__payload.html#ad480749a0f62d2b65439f6db75180c9b',1,'uhd::rfnoc::chdr::strs_payload::status'],['../classuhd_1_1rfnoc_1_1chdr_1_1strs__payload.html#abcf028665b24a1bfbcc5fabe3ee616a0',1,'uhd::rfnoc::chdr::strs_payload::status']]],
  ['status_5finfo_27',['status_info',['../classuhd_1_1rfnoc_1_1chdr_1_1strs__payload.html#a8d704f4acb6f62b70336b7f1c94a3f07',1,'uhd::rfnoc::chdr::strs_payload']]],
  ['step_28',['step',['../structuhd__range__t.html#af833ecfd9e3c97e02b42f64cbe9b70ad',1,'uhd_range_t']]],
  ['stop_29',['stop',['../structuhd__range__t.html#aa5087b5f114a9dbc91c0b448af10a156',1,'uhd_range_t']]],
  ['stop_5fon_5fseq_5ferror_5fenabled_30',['stop_on_seq_error_enabled',['../classuhd_1_1rfnoc_1_1chdr_1_1strs__payload.html#aef2ca00989089d48d2ed13e759e86157',1,'uhd::rfnoc::chdr::strs_payload']]],
  ['stream_5fcmd_31',['stream_cmd',['../structuhd_1_1rfnoc_1_1stream__cmd__action__info.html#af61e2768b2eb7152b5a5985c38219864',1,'uhd::rfnoc::stream_cmd_action_info']]],
  ['stream_5fmode_32',['stream_mode',['../structuhd_1_1stream__cmd__t.html#afc034937887f08dc6119cf96b0c02f5d',1,'uhd::stream_cmd_t::stream_mode'],['../structuhd__stream__cmd__t.html#a7a554a47849307827e4e067a3c7a3db3',1,'uhd_stream_cmd_t::stream_mode']]],
  ['stream_5fnow_33',['stream_now',['../structuhd_1_1stream__cmd__t.html#a0b2ebd1dedd814355c3fcd51af7d1eb1',1,'uhd::stream_cmd_t::stream_now'],['../structuhd__stream__cmd__t.html#a49d87875f02323627803db3df305b43b',1,'uhd_stream_cmd_t::stream_now']]]
];
